@@ -2,6 +2,7 @@
 
 # Author: Colin Weber
 # Contact: colin.weber.27@gmail.com
+# Contributors: Adrian Valverde, Dwaipayan Ray
 # License: MIT
 # sklearn License: BSD 3 clause
 
@@ -9,7 +10,7 @@
 import numpy as np
 import matplotlib.pyplot as plt
 import scipy.stats
-from GMMClusteringAlgorithms.classes._base import GaussianMixtureBase
+from ._base import GaussianMixtureBase
 from sklearn.mixture import BayesianGaussianMixture as BGM
 from ..sklearn_mixture_piicr import StrictBayesianGaussianMixture
 from ._data_frame import num_bins
@@ -191,9 +192,12 @@ class BayesianGaussianMixture(GaussianMixtureBase):
 
         A Strict Bayesian Gaussian Mixture is a Bayesian Gaussian Mixture
         in which the number of components is required to remain at the
-        value given by 'n_components'. This is a special case of the regular
-        Bayesian Gaussian Mixture in which the number of components is
-        allowed to be lower than 'n_components'.
+        value given by 'n_components'. The fitting algorithm accomplishes
+        this by returning the model parameters as soon as the number of
+        samples in the smallest cluster gets below 0.1% of all the samples
+        in the data set. Therefore, this model rarely converges. In this way,
+        it is a special case of the regular Bayesian Gaussian Mixture,
+        where the number of components is allowed to be lower than 'n_components'.
 
         Parameters
         x : array-like, shape (n_samples, n_attributes)
@@ -217,7 +221,10 @@ class BayesianGaussianMixture(GaussianMixtureBase):
 
     def _calc_secondary_centers_unc(self, c1s, c1s_err, c2s,
                                     c2s_err, data_frame_object):
-        """Calculate the coordinates of the cluster centers for the coordinate system that was not used for the fit.
+        """Calculate the coordinates of the cluster centers for the coordinate system
+        that was not used for the fit.
+
+        Standard errors are calculated with typical standard error propagation methods.
 
         Parameters
         ----------
@@ -227,7 +234,7 @@ class BayesianGaussianMixture(GaussianMixtureBase):
             of the cluster centers.
 
         c1s_err : array-like, shape (n_components,)
-            The uncertainty in the c1s.
+            The standard error in the c1s.
 
         c2s : array-like, shape (n_components,)
             The y-coordinates of the cluster centers if clustering
@@ -235,7 +242,7 @@ class BayesianGaussianMixture(GaussianMixtureBase):
             of the cluster centers.
 
         c2s_err : array-like, shape (n_components,)
-            The uncertainty in the c2s.
+            The standard error in the c2s.
 
         data_frame_object : object from the class DataFrame
             The object that contains the processed data and
@@ -390,6 +397,8 @@ class BayesianGaussianMixture(GaussianMixtureBase):
         curve to each dimension of each cluster and uses the
         statistics from the fits to calculate the centers.
 
+        This method was written by Dwaipayan Ray and Adrian Valverde.
+
         Parameters
         ----------
         data_frame_object : object from the class DataFrame
@@ -402,17 +411,15 @@ class BayesianGaussianMixture(GaussianMixtureBase):
 
         cp = data_frame_object.data_array_
 
-        c1_stuff, c2_stuff = {}, {}  # c1-s and c2-s of the spots in
-        # each cluster, dictionary index as the cluster number
-        ions_psp_dict = {}  # ions per spot (psp), dictionary
-        # index as the cluster number
-        rel_popu_psp_dict = {}  # relative population per spot
-        # (psp), dictionary index as the cluster number
+        c1_stuff, c2_stuff = {}, {}
+        # c1-s and c2-s of the spots in each cluster, with dictionary indexes as the cluster numbers
+        ions_psp_dict = {}  # ions per spot (psp), with dictionary indexes as the cluster numbers
+        rel_popu_psp_dict = {}
+        # relative population per spot (psp), with dictionary indexes as the cluster numbers
         ions_psp = []  # ions per spot (psp)
         rel_popu_psp = []  # relative population per spot (psp)
 
-        cluster_ind = np.arange(0, self.n_comps_found_)  # array of
-        # cluster numbers
+        cluster_ind = np.arange(0, self.n_comps_found_)  # array of cluster numbers
         for i in cluster_ind:
             if self.coordinates == 'Cartesian':
                 c1_stuff['%i' % i] = cp[self.labels_ ==
@@ -436,8 +443,7 @@ class BayesianGaussianMixture(GaussianMixtureBase):
             rel_popu_psp_dict['%i' % i] = 1.0 * len(
                 c1_stuff['%i' % i]) / len(cp[:, 0])
 
-            ions_psp.append(len(c1_stuff['%i' % i]))
-            # ions per spot
+            ions_psp.append(len(c1_stuff['%i' % i])) # ions per spot
             rel_popu_psp.append(1.0 * len(c1_stuff['%i' % i]) /
                                 len(cp[:, 0]))
 
@@ -450,8 +456,7 @@ class BayesianGaussianMixture(GaussianMixtureBase):
         cluster_err = []
         ips = []
 
-        c1_clusters, c2_clusters = {}, {}  # all c1's and c2's of the
-        # ion-hits in each cluster
+        c1_clusters, c2_clusters = {}, {}  # all c1's and c2's of the ion-hits in each cluster
 
         for i in cluster_ind:
             plt.figure()
@@ -687,7 +692,7 @@ class BayesianGaussianMixture(GaussianMixtureBase):
 
         Given a data frame object that has already been used
         to generate histograms for each dimension of data, this
-        function will graph a GMM fit over each dimension.
+        method will graph a GMM fit over each dimension.
 
         Parameters
         ----------
@@ -859,6 +864,8 @@ class BayesianGaussianMixture(GaussianMixtureBase):
     def show_results(self, data_frame_object):
         """Display the clustering results.
 
+        This method was written by Dwaipayan Ray and Adrian Valverde.
+
         Parameters
         ----------
         data_frame_object : object from the class DataFrame
