@@ -3,6 +3,7 @@ Gaussian Mixture Models from the sklearn package."""
 
 # Author: Colin Weber
 # Contact: colin.weber.27@gmail.com
+# Contributors: Adrian Valverde and Dwaipayan Ray
 # License: MIT
 
 import os
@@ -262,6 +263,9 @@ class DataFrame:
     def process_lmf(self):
         """Process the .lmf data file.
 
+        This method was written by Dwaipayan Ray and
+        Adrian Valverde.
+
         Returns
         --------
         lmf_start_time_int : int
@@ -285,17 +289,24 @@ class DataFrame:
         file.seek(0, 2)  # Go to the last byte of the file '2'=os.SEEK_END
         LMFileSize = file.tell()  # Returns the position of the last byte = file's size
         file.seek(0, 0)  # Go to the beginning of the file '0'=os.SEEK_BEG
-        LMHeadVersion = (struct.unpack('<I', file.read(4)))[0]  # Read 4 bytes and converts them to unsigned int
-        LMDataFormat = struct.unpack('<I', file.read(4))[0]  # Read 4 bytes and converts them to unsigned int
-        LM64NumberOfCoordinates = struct.unpack('<Q', file.read(8))[
-            0]  # Read 8 bytes and converts them to unsigned int
-        LM64HeaderSize = struct.unpack('<Q', file.read(8))[0]  # Read 8 bytes and converts them to unsigned int
-        LM64UserHeaderSize = struct.unpack('<Q', file.read(8))[0]  # Read 8 bytes and converts them to unsigned int
-        LM64NumberOfEvents = struct.unpack('<Q', file.read(8))[0]  # Read 8 bytes and converts them to unsigned int
+        LMHeadVersion = (struct.unpack('<I', file.read(4)))[0]
+        # Read 4 bytes and converts them to unsigned int
+        LMDataFormat = struct.unpack('<I', file.read(4))[0]
+        # Read 4 bytes and converts them to unsigned int
+        LM64NumberOfCoordinates = struct.unpack('<Q', file.read(8))[0]
+        # Read 8 bytes and converts them to unsigned int
+        LM64HeaderSize = struct.unpack('<Q', file.read(8))[0]
+        # Read 8 bytes and converts them to unsigned int
+        LM64UserHeaderSize = struct.unpack('<Q', file.read(8))[0]
+        # Read 8 bytes and converts them to unsigned int
+        LM64NumberOfEvents = struct.unpack('<Q', file.read(8))[0]
+        # Read 8 bytes and converts them to unsigned int
         file.seek(4, 1)  # skip 4B '1'=os.SEEK_CUR
-        LMStartTime = struct.unpack('<Q', file.read(8))[0]  # Read 8 bytes and converts them to unsigned int
+        LMStartTime = struct.unpack('<Q', file.read(8))[0]
+        # Read 8 bytes and converts them to unsigned int
         file.seek(4, 1)  # skip 4B '1'=os.SEEK_CUR
-        LMStopTime = struct.unpack('<Q', file.read(8))[0]  # Read 8 bytes and converts them to unsigned int
+        LMStopTime = struct.unpack('<Q', file.read(8))[0]
+        # Read 8 bytes and converts them to unsigned int
 
         # Read the data block
         dataBlockOffset = LM64HeaderSize + LM64UserHeaderSize
@@ -481,7 +492,9 @@ class DataFrame:
     def return_processed_data(self):
         """Return the processed data as an Excel file.
 
-        This will have to be saved separately.
+        The returned writer will have to be saved separately with the
+        method writer.save(). This method was written by Dwaipayan Ray
+        and Adrian Valverde.
 
         Returns
         -------
@@ -513,9 +526,13 @@ class DataFrame:
     def get_data_figure(self):
         """Plot the data and return the figure.
 
-        This will have to be shown in a separate command and
-        saved separately. The function also returns a string
-        that can be used as a file name for the figure.
+        The data figure will have to be shown after returning
+        using the method plt.show(), and saved after retuning
+        using the method plt.savefig(). The method returns a
+        string that can be used as a file name for the figure.
+
+        This method was written by Dwaipayan Ray and Adrian
+        Valverde.
 
         Returns
         -------
