@@ -2,6 +2,7 @@
 
 # Author: Colin Weber
 # Contact: colin.weber.27@gmail.com
+# Contributors: Adrian Valverde and Dwaipayan Ray
 # License: MIT
 # sklearn License: BSD 3 clause
 
@@ -174,7 +175,10 @@ class PhaseFirstGaussianModel(GaussianMixtureBase):
 
     def _calc_secondary_centers_unc(self, c1s, c1s_err, c2s,
                                     c2s_err, data_frame_object):
-        """Calculate the coordinates of the cluster centers for the coordinate system that was not used for the fit.
+        """Calculate the coordinates of the cluster centers for the coordinate system that was not used
+        for the fit.
+
+        Standard Errors are calculated with typical standard error propagation methods.
 
         Parameters
         ----------
@@ -184,7 +188,7 @@ class PhaseFirstGaussianModel(GaussianMixtureBase):
             of the cluster centers.
 
         c1s_err : array-like, shape (n_components,)
-            The uncertainty in the c1s.
+            The standard error in the c1s.
 
         c2s : array-like, shape (n_components,)
             The y-coordinates of the cluster centers if clustering
@@ -192,7 +196,7 @@ class PhaseFirstGaussianModel(GaussianMixtureBase):
             of the cluster centers.
 
         c2s_err : array-like, shape (n_components,)
-            The uncertainty in the c2s.
+            The standard error in the c2s.
 
         data_frame_object : object from the class DataFrame
             The object that contains the processed data and
@@ -300,6 +304,8 @@ class PhaseFirstGaussianModel(GaussianMixtureBase):
         curve to each dimension of each cluster and uses the
         statistics from the fits to calculate the centers.
 
+        This method was written by Dwaipayan Ray and Adrian Valverde.
+
         Parameters
         ----------
         data_frame_object : object from the class DataFrame
@@ -632,7 +638,7 @@ class PhaseFirstGaussianModel(GaussianMixtureBase):
 
         Given a data frame object that has already been used
         to generate histograms for each dimension of data, this
-        function will graph a GMM fit over each dimension.
+        method will graph a GMM fit over each dimension.
 
         Parameters
         ----------
@@ -788,6 +794,8 @@ class PhaseFirstGaussianModel(GaussianMixtureBase):
     def show_results(self, data_frame_object):
         """Display the clustering results.
 
+        This method was written by Dwaipayan Ray and Adrian Valverde.
+
         Parameters
         ----------
         data_frame_object : object from the class DataFrame
