@@ -1,6 +1,7 @@
 """Bayesian Gaussian Mixture Model."""
 # Author: Wei Xue <xuewei4d@gmail.com>
 #         Thierry Guillemot <thierry.guillemot.work@gmail.com>
+# Contributor: Colin Weber <colin.weber.27@gmail.com>
 # License: BSD 3 clause
 
 import math
@@ -63,11 +64,13 @@ def _log_wishart_norm(degrees_of_freedom, log_det_precisions_chol, n_features):
 
 
 class StrictBayesianGaussianMixture(StrictBayesianBaseMixture):
-    """Variational Bayesian estimation of a Gaussian mixture.
+    """Strict Variational Bayesian estimation of a Gaussian mixture.
 
     This class allows to infer an approximate posterior distribution over the
-    parameters of a Gaussian mixture distribution. The effective number of
-    components can be inferred from the data.
+    parameters of a Gaussian mixture distribution. The number of components
+    is given by the value of n_components, and remains fixed throughout the fit.
+    In order to accomplish this, the fit stops when the smallest cluster contains 0.1%
+    of the samples in the data set. Therefore, it rarely converges.
 
     This class implements two types of prior for the weights distribution: a
     finite mixture model with Dirichlet distribution and an infinite mixture
@@ -76,18 +79,14 @@ class StrictBayesianGaussianMixture(StrictBayesianBaseMixture):
     maximum number of components (called the Stick-breaking representation).
     The number of components actually used almost always depends on the data.
 
-    .. versionadded:: 0.18
+    .. version:: 0.1
 
     Read more in the :ref:`User Guide <bgmm>`.
 
     Parameters
     ----------
     n_components : int, defaults to 1.
-        The number of mixture components. Depending on the data and the value
-        of the `weight_concentration_prior` the model can decide to not use
-        all the components by setting some component `weights_` to values very
-        close to zero. The number of effective components is therefore smaller
-        than n_components.
+        The number of mixture components.
 
     covariance_type : {'full', 'tied', 'diag', 'spherical'}, defaults to 'full'
         String describing the type of covariance parameters to use.
